@@ -87,13 +87,19 @@ void Scheduler::setBusyTimeout(int timeout)
     m_busyTimeout = timeout;
 }
 
+int Scheduler::numberOfCollectionQueued() const
+{
+    return m_collectionQueue.count();
+}
+
 void Scheduler::collectDirtyCollections()
 {
     KConfig config(Akonadi::ServerManager::addNamespace(QStringLiteral("baloorc")));
     KConfigGroup group = config.group("Akonadi");
     //Store collections where we did not manage to index all, we'll need to do a full sync for them the next time
-    QHash<Akonadi::Collection::Id, QQueue<Akonadi::Item::Id>>::iterator it = m_queues.begin();
-    for (; it != m_queues.end(); it++) {
+    QHash<Akonadi::Collection::Id, QQueue<Akonadi::Item::Id>>::ConstIterator it = m_queues.constBegin();
+    QHash<Akonadi::Collection::Id, QQueue<Akonadi::Item::Id>>::ConstIterator end = m_queues.constEnd();
+    for (; it != end; ++it) {
         if (!it.value().isEmpty()) {
             m_dirtyCollections.insert(it.key());
         }
@@ -236,7 +242,9 @@ void Scheduler::slotIndexingFinished(KJob *job)
     if (job->error()) {
         qCWarning(AKONADI_INDEXER_AGENT_LOG) << "Indexing failed: " << job->errorString();
     } else {
-        m_dirtyCollections.remove(job->property("collection").value<Akonadi::Collection::Id>());
+        const Akonadi::Collection::Id collectionId = job->property("collection").value<Akonadi::Collection::Id>();
+        m_dirtyCollections.remove(collectionId);
+        status(Akonadi::AgentBase::Idle, i18n("Collection \"%1\" indexed", collectionId));
     }
     m_currentJob = 0;
     m_processTimer.start();
